@@ -32,6 +32,7 @@ from virtualenv import subprocess
 from addon import Addon
 from repository import Repository
 from pwd import getpwnam
+from urllib import urlretrieve
 
 class NoEnvironmentConfigFileError(RuntimeError):
     def __init__(self, filepath):
@@ -44,21 +45,20 @@ class NoVersionAvailableError(RuntimeError):
         self.message = "No version available (%s)" % version
 
 class OpenERPEnvironment:
-    def __init__(self, sources=None, config_filename=defaults.config_filename, init=False, version='6.0'):
+    def __init__(self, path, config_filename=defaults.config_filename, init=False, version='6.0'):
         """
         Create an instance of OpenERPEnvironment class.
 
         Arguments:
         config_filename -- Full path to the configuration file.
         """
-        if not sources is None and not exists(sources):
-            makedirs(sources)
+        if not path is None and not exists(path):
+            makedirs(path)
         if exists(config_filename):
             self.config_filename = abspath(config_filename)
             self.root_path = dirname(self.config_filename)
         elif init:
-            path = dirname(config_filename)
-            src_config_filename = config_filename
+            src_config_filename = defaults.src_config_filename[version]
             dst_config_filename = join(abspath(path), 'environment.conf')
 
             if not lexists(path):
@@ -75,10 +75,6 @@ class OpenERPEnvironment:
                 raise NoVersionAvailableError(version)
             self._config.update(defaults.version_configuration[version])
             self._config['Environment.root'] = self.root_path
-            if not sources is None:
-                default_sources = self._config['Environment.sources']
-                symlink(sources, default_sources)
-                self._config['Environment.sources'] = sources
             self.environments = []
             self.create_python_environment(defaults.python_environment)
             self.save(init=True)
